eric6/Sessions/SessionFile.py

branch
jsonfiles
changeset 8025
aaad60a23960
parent 8016
e484fc67677e
child 8031
ce5858a237d2
diff -r 56359a72ab10 -r aaad60a23960 eric6/Sessions/SessionFile.py
--- a/eric6/Sessions/SessionFile.py	Thu Jan 28 18:29:31 2021 +0100
+++ b/eric6/Sessions/SessionFile.py	Fri Jan 29 14:18:50 2021 +0100
@@ -4,8 +4,7 @@
 #
 
 """
-Module implementing a class representing the project debugger properties
-JSON file.
+Module implementing a class representing the session JSON file.
 """
 
 import json
@@ -22,7 +21,7 @@
 
 class SessionFile(QObject):
     """
     Class representing the project debugger properties JSON file.
     """
     def __init__(self, isGlobal: bool, parent: QObject = None):
         """
@@ -22,7 +21,7 @@
 class SessionFile(QObject):
     """
-    Class representing the project debugger properties JSON file.
+    Class representing the session JSON file.
     """
     def __init__(self, isGlobal: bool, parent: QObject = None):

eric ide

mercurial